Class: Ella::GemfileGenerator
- Defined in:
- lib/ella/generator/gemfile_generator.rb
Overview
Generates a Gemfile with the necessary dependencies for an ella project, and runs Bundle to install those dependencies.
Instance Method Summary collapse
Methods inherited from Generator
Constructor Details
This class inherits a constructor from Ella::Generator